@@ -17,7 +17,7 @@
 #'   \href{ftp://ftp.fu-berlin.de/tex/CTAN/macros/latex/contrib/apa6/apa6.pdf}{documentation}
 #'   to find out about class options such as paper size or draft watermarks.
 #'
-#'   Please refer to the \href{http://frederikaust.com/papaja_man/r-markdown-components.html#yaml-front-matter}{\pkg{papaja} online-manual}
+#'   Please refer to the \href{https://frederikaust.com/papaja_man/r-markdown-components.html#yaml-front-matter}{\pkg{papaja} online-manual}
 #'   for additional information on available YAML front matter settings.
 #'   Note that the available settings for DOCX documents are more limited
 #'   than for PDF documents.
@@ -25,7 +25,7 @@
 #'   When creating PDF documents the output device for figures defaults to
 #'   \code{c("pdf", "png")}, so that each figure is saved in all four formats
 #'   at a resolution of 300 dpi.
-#' @return R Markdown output format to pass to [rmarkdown::render()]
+#' @return R Markdown output format to pass to [rmarkdown::render()].
 #' @seealso [bookdown::pdf_document2()], [bookdown::word_document2()]
 #' @export
 
@@ -437,6 +437,7 @@ pdf_pre_processor <- function(metadata, input_file, runtime, knit_meta, files_di
       metadata$lang
       , english = "en-EN"
       , american = "en-US"
+      , german = "de-DE"
       , metadata$lang
     )
   }
